@@ -1,14 +1,12 @@
-#!/usr/bin/env python
-
 # Fonts:
 
-fpdf_charwidths = {"courier": {}}
-
-for i in range(256):
-    fpdf_charwidths["courier"][chr(i)] = 600
-    fpdf_charwidths["courierB"] = fpdf_charwidths["courier"]
-    fpdf_charwidths["courierI"] = fpdf_charwidths["courier"]
-    fpdf_charwidths["courierBI"] = fpdf_charwidths["courier"]
+courier = {chr(i): 600 for i in range(256)}
+fpdf_charwidths = {
+    "courier": courier,
+    "courierB": courier,
+    "courierI": courier,
+    "courierBI": courier,
+}
 
 fpdf_charwidths["helvetica"] = {
     "\x00": 278,
